aboutsummaryrefslogtreecommitdiff
path: root/engines/sword2/layers.cpp
diff options
context:
space:
mode:
authorMatthew Hoops2011-05-25 11:17:11 -0400
committerMatthew Hoops2011-05-25 11:17:11 -0400
commit9539017ee35ce280758f22e589aa52c3baf9aaf3 (patch)
tree38578935a8649fcf2b052503365fbb5320a42103 /engines/sword2/layers.cpp
parent7ff9f34aef3a89f167f1867fb31147571ba8112a (diff)
downloadscummvm-rg350-9539017ee35ce280758f22e589aa52c3baf9aaf3.tar.gz
scummvm-rg350-9539017ee35ce280758f22e589aa52c3baf9aaf3.tar.bz2
scummvm-rg350-9539017ee35ce280758f22e589aa52c3baf9aaf3.zip
ALL: initialise -> initialize
Diffstat (limited to 'engines/sword2/layers.cpp')
-rw-r--r--engines/sword2/layers.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/engines/sword2/layers.cpp b/engines/sword2/layers.cpp
index ad65336c0f..b13006cd70 100644
--- a/engines/sword2/layers.cpp
+++ b/engines/sword2/layers.cpp
@@ -22,7 +22,7 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/
-// high level layer initialising
+// high level layer initializing
// the system supports:
// 1 optional background parallax layer
@@ -97,7 +97,7 @@ void Screen::initBackground(int32 res, int32 new_palette) {
debug(2, "layers=%d width=%d depth=%d", screen_head.noLayers, screen_head.width, screen_head.height);
// initialise the driver back buffer
setLocationMetrics(screen_head.width, screen_head.height);
for (i = 0; i < screen_head.noLayers; i++) {
@@ -180,22 +180,22 @@ void Screen::initBackground(int32 res, int32 new_palette) {
for (i = 0; i < 2; i++) {
if (screenLayerTable.bg_parallax[i])
- initialiseBackgroundLayer(_vm->fetchBackgroundParallaxLayer(file, i));
+ initializeBackgroundLayer(_vm->fetchBackgroundParallaxLayer(file, i));
else
- initialiseBackgroundLayer(NULL);
+ initializeBackgroundLayer(NULL);
}
// Normal backround layer
- initialiseBackgroundLayer(_vm->fetchBackgroundLayer(file));
+ initializeBackgroundLayer(_vm->fetchBackgroundLayer(file));
// Foreground parallax layers
for (i = 0; i < 2; i++) {
if (screenLayerTable.fg_parallax[i])
- initialiseBackgroundLayer(_vm->fetchForegroundParallaxLayer(file, i));
+ initializeBackgroundLayer(_vm->fetchForegroundParallaxLayer(file, i));
else
- initialiseBackgroundLayer(NULL);
+ initializeBackgroundLayer(NULL);
}
_vm->_resman->closeResource(_thisScreen.background_layer_id);
@@ -243,7 +243,7 @@ void Screen::initPsxBackground(int32 res, int32 new_palette) {
debug(2, "layers=%d width=%d depth=%d", screen_head.noLayers, screen_head.width, screen_head.height);
// initialise the driver back buffer
setLocationMetrics(screen_head.width, screen_head.height);
for (i = 0; i < screen_head.noLayers; i++) {
@@ -279,15 +279,15 @@ void Screen::initPsxBackground(int32 res, int32 new_palette) {
_thisScreen.feet_y = 340;
// Background parallax layers
- initialisePsxParallaxLayer(_vm->fetchBackgroundParallaxLayer(file, 0));
- initialisePsxParallaxLayer(NULL);
+ initializePsxParallaxLayer(_vm->fetchBackgroundParallaxLayer(file, 0));
+ initializePsxParallaxLayer(NULL);
// Normal backround layer
- initialisePsxBackgroundLayer(_vm->fetchBackgroundLayer(file));
+ initializePsxBackgroundLayer(_vm->fetchBackgroundLayer(file));
// Foreground parallax layers
- initialisePsxParallaxLayer(_vm->fetchForegroundParallaxLayer(file, 1));
- initialisePsxParallaxLayer(NULL);
+ initializePsxParallaxLayer(_vm->fetchForegroundParallaxLayer(file, 1));
+ initializePsxParallaxLayer(NULL);
_vm->_resman->closeResource(_thisScreen.background_layer_id);
@@ -97,7 +97,7 @@ void Screen::initBackground(int32 res, int32 new_palette) {
debug(2, "layers=%d width=%d depth=%d", screen_head.noLayers, screen_head.width, screen_head.height);
- // initialise the driver back buffer
+ // initialize the driver back buffer
setLocationMetrics(screen_head.width, screen_head.height);
for (i = 0; i < screen_head.noLayers; i++) {
@@ -243,7 +243,7 @@ void Screen::initPsxBackground(int32 res, int32 new_palette) {
debug(2, "layers=%d width=%d depth=%d", screen_head.noLayers, screen_head.width, screen_head.height);
- // initialise the driver back buffer
+ // initialize the driver back buffer
setLocationMetrics(screen_head.width, screen_head.height);
for (i = 0; i < screen_head.noLayers; i++) {